<template>
  <div>
    <div
      class="rounded-lg shadow-lg ring-1 ring-black ring-opacity-5 overflow-hidden w-[30rem]"
      style="direction: rtl !important"
    >
      <div class="bg-white">
        <div class="py-6 px-6 bg-[#ffe8e8] flex justify-between rounded-b-3xl">
          <div>سبد خرید من</div>
          <div>
            {{ UserShopCart.length }} کالا
            <span class="bg-white text-black rounded-full h-8 w-8 mr-3">
              <img src="trash.svg" alt="" class="inline" srcset="" />
            </span>
          </div>
        </div>
        <nuxt-link
          to=""
          class="-m-3 my-3 mx-3 p-3 flex justify-center rounded-xl border-0 bg-[#f8f6f6] hover:bg-gray-50"
        >
          هزینه ارسال
        </nuxt-link>
        <div
          class="mt-8 mx-3 large-2"
          style="max-height: 250px; overflow-y: scroll"
        >
          <div class="flow-root">
            <ul role="list" class="-my-6 divide-y divide-gray-200">
              <li
                v-for="(product, index) in UserShopCart"
                :key="index"
                class="flex py-6"
              >
                <div
                  class="h-24 w-24 flex-shrink-0 overflow-hidden rounded-md border border-gray-200"
                >
                  <img
                    :src="`https://2sote.com/File/Product/Tiny/${product.productImg}`"
                    alt="Salmon orange fabric pouch with match zipper, gray zipper pull, and adjustable hip belt."
                    class="h-full w-full object-cover object-center"
                  />
                </div>

                <div class="ml-4 flex flex-1 flex-col mr-3">
                  <div>
                    <div
                      class="flex justify-between text-base font-medium text-gray-900"
                    >
                      <h3>
                        <a href="#"> {{ product.productName }}</a>
                      </h3>
                      <p
                        v-if="product.oldPrice !== product.price"
                        class="mt-1 text-sm text-gray-500"
                      >
                        <span
                          class="bg-red-400 px-3 py-0.5 text-white rounded-full"
                        >
                          {{ discountProduct(product.price, product.oldPrice) }}
                        </span>
                      </p>
                    </div>
                    <div class="flex my-2">
                      <div
                        class="mt-1 text-sm text-gray-500 flex-grow flex items-center"
                      >
                        <button-number
                          :count="product.count"
                          :productId="product.productID"
                          :orderMin="product.orderMin"
                        />

                        <!-- <img
                          src="fi-rr-add.svg"
                          width="21px"
                          height="21px"
                          alt=""
                          srcset=""
                        />
                        <span class="inline text-lg mx-2">{{
                          product.count
                        }}</span>
                        <img
                          v-if="product.count == 1"
                          src="trash.svg"
                          width="15px"
                          height="19px"
                          alt=""
                          class="inline"
                          srcset=""
                        />

                        <img
                          v-else
                          class="inline"
                          src="fi-rr-add.svg"
                          width="15px"
                          height="19px"
                          alt=""
                          srcset=""
                        /> -->
                      </div>
                      <div class="flex-shrink">
                        <p class="text-sm font-medium text-gray-900">
                          {{ priceFormatting(product.price) }}
                        </p>
                        <p
                          v-if="product.oldPrice !== product.price"
                          class="text-sm font-medium text-gray-900 line-through"
                        >
                          {{product.oldPrice}}
                        </p>
                      </div>
                    </div>
                  </div>
                  <div class="flex flex-1 items-end justify-end text-sm">
                    <div class="flex">
                      <p
                        type="button"
                        class="font-medium text-indigo-600 hover:text-indigo-500"
                      >
                        قیمت نهایی : {{ priceFormatting(product.sumPrice) }}
                      </p>
                    </div>
                  </div>
                </div>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <div class="bg-white sm:py-4">
        <div>
          <ul role="list" class="mt-4">
            <li class="text-base truncate">
              <nuxt-link
                to=""
                class="-m-3 my-3 mx-3 p-3 flex justify-center rounded-xl border-0 bg-[#f8f6f6] hover:bg-gray-50"
              >
                میزان سود شما از این خرید
              </nuxt-link>
            </li>

            <li class="text-base truncate">
              <nuxt-link
                to=""
                class="-m-3 my-3 mx-3 p-3 flex justify-center rounded-xl border bg-[#ed3d53] text-white"
              >
                نهایی کردن خرید (مبلغ قابل پرداخت)
              </nuxt-link>
            </li>
          </ul>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import ButtonNumber from '../../components/Checkout/ButtonNumber'

export default {
  components: {
    ButtonNumber,
  },
  data() {
    return {
      number: 1,
    }
  },
  computed: {
    UserShopCart() {
      return this.$store.getters['order/GetUserShopCart']
    },
   
  },

  methods: {
 
    discountProduct(price1, price2) {
      return '%' + Math.round(((price2 - price1) / price2) * 100)
    },
    priceFormatting(item) {
      return (
        'تومان' + ' ' + item.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ',')
      )
    },
  },
}
</script>

<style lang="scss" scoped>
.large-2::-webkit-scrollbar-track {
  border: 1px solid #fff;
  padding: 2px 0;
  background-color: #fff;
}

.large-2::-webkit-scrollbar {
  width: 10px;
}

.large-2::-webkit-scrollbar-thumb {
  border-radius: 10px;
  box-shadow: inset 0 0 6px rgba(84, 84, 84, 0.3);
  background-color: #737272;
}
</style>
